<?xml version="1.0" encoding="UTF-8"?>
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http:///extensionmodel.ecore" xmlns:extensionmodel="http:///extensionmodel.ecore" xmlns:fdl="http://www.ibm.com/workflow/2003" xmlns:wpc="http://www.ibm.com/xmlns/prod/websphere/business-process/6.0.0/" xmlns:bpel="http://schemas.xmlsoap.org/ws/2004/03/business-process/" xmlns:xalan="http://xml.apache.org/xalan" extension-element-prefixes="xalan" exclude-result-prefixes="fdl wpc bpel" version="1.0">
	<!--
		*****************************************************************************************************************************
			IBM Confidential
			OCO Source Materials 
			5655-FLW (C) Copyright IBM Corporation 2003, 2004, 2005, 2006.
			The source code for this program is not published or otherwise
			divested of its trade secrets, irrespective of what has been
			deposited with the U.S. Copyright Office.
		*****************************************************************************************************************************
		    	Version:  WBI 6.0
		*****************************************************************************************************************************
		    	Task:      Create a BPELEX file that is required for the generation of deploy code of sub-process invocations
		*****************************************************************************************************************************
	       	Author: Jens Grotrian (jgr@de.ibm.com)
		*****************************************************************************************************************************
	 -->
	<xsl:strip-space elements="*"/>
	<xsl:output method="xml" indent="yes" xalan:indent-amount="5"/>
	<!--
		*****************************************************************************************************************************
	       Parameters
		*****************************************************************************************************************************
	-->
	<!-- "outputExtDir: output directory relative to WSADIE workspace root" -->
	<xsl:param name="outputExtDir" select="'FDL2BPEL'"/>
	<!-- "bpelpath": path of directory which contains the BPEL file(s) -->
	<xsl:param name="bpelpath" select="''"/>
	<!-- "process-name": the name of the FDL process to be converted -->
	<xsl:param name="process-name"/>
	<!-- "end of line" character string -->
	<xsl:param name="eol" select='"&#xA;"'/>
	<!-- 
		*****************************************************************************************************************************
		Initial template 
		*****************************************************************************************************************************
	-->
	<xsl:template match="/">
		<xsl:apply-templates select="fdl:definitions/fdl:process[ @name = $process-name and descendant::fdl:processActivity ] | fdl:definitions/fdl:update/fdl:process[ @name = $process-name and descendant::fdl:processActivity ]" mode="business-process"/>
	</xsl:template>
	<!--
		*****************************************************************************************************************************
 		"business-process" template:
 		
		Creates a "BPELEX" file for each "fdl:process" that contains a descendant element "fdl:processActivity".
		(writes the result in a separate file with extension ".bpelex")
		*****************************************************************************************************************************
	-->
	<xsl:template match="fdl:process" mode="business-process">
		<xsl:variable name="process" select="current()"/>
		<xsl:variable name="bpel-file-name" select="concat(@name, '.bpel')"/>
		<xsl:variable name="bpel-file-name_with_path" select="concat($bpelpath, $bpel-file-name)"/>
		<xsl:variable name="bpelex-file-name" select="concat(@name, '.bpelex')"/>
		<xsl:variable name="bpel-process" select="document($bpel-file-name_with_path)//bpel:process"/>
		<xsl:variable name="outputExtDir1">
			<xsl:choose>
				<xsl:when test="substring($outputExtDir, 1, 1) = '/' or substring($outputExtDir, 1, 1) = '\' or substring($outputExtDir, 1, 1) = '.'">
					<xsl:value-of select="substring($outputExtDir, 2)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$outputExtDir"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<extensionmodel:ExtensionMap xmi:version="2.0" xmlns:xmi="http://www.omg.org/XMI" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:com.ibm.etools.ctc.bpel.ui.uiextensionmodel="http:///com/ibm/etools/ctc/bpel/ui/uiextensionmodel.ecore" xmlns:extensionmodel="http:///extensionmodel.ecore" namespace="http://com.ibm.etools.ctc.bpel.ui/">
			<xsl:for-each select="$bpel-process/bpel:partnerLinks/bpel:partnerLink">
				<xsl:if test="substring-before(@name, '_PL') = $process//fdl:processActivity/fdl:process/@name">
					<extensions>
						<extendedObject href="{concat(concat($bpel-file-name, '#//@partnerLinks/@children.'), position() - 1)}"/>
						<extensionObject bPELFileName="{concat(concat(concat(concat('/', translate($outputExtDir1, '.\', '//')), '/'), substring-before(@name, '_PL')), '.bpel')}" bPELPartnerName="{@name}" kind="Bpel" xsi:type="com.ibm.etools.ctc.bpel.ui.uiextensionmodel:PartnerLinkExtension"/>
					</extensions>
				</xsl:if>
			</xsl:for-each>
		</extensionmodel:ExtensionMap>
	</xsl:template>
</xsl:transform>
