<?xml version="1.0" encoding="UTF-8"?>
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:wsdls="http://schemas.xmlsoap.org/wsdl/" xmlns:redirect="http://xml.apache.org/xalan/redirect" xmlns:xalan="http://xml.apache.org/xalan" xmlns:java="http://xml.apache.org/xalan/java" extension-element-prefixes="redirect xalan java" version="1.0">
	<!--
			  BEGIN CMVC
			  *************************************************************************
			  
			  Workfile: BPCSRVR/ws/code/workflow.fdl2bpel/src/com/ibm/bpe/fdl2bpel/converter/v602/xfdl2bpel_java.xsl, WAS.workflow, WBI602.BPCSRVR, m0705.08
			  Last update: 06/11/24 08:03:07
			  SCCS path, id: /family/botp/vc/10/8/3/1/s.71 1.6
			  
			  *************************************************************************
			  END CMVC
			  BEGIN COPYRIGHT
			  *************************************************************************
			  
			  IBM Confidential
			  OCO Source Materials
			  5655-FLW (C) Copyright IBM Corporation 2003, 2006.
			  The source code for this program is not published or otherwise
			  divested of its trade secrets, irrespective of what has been
			  deposited with the U.S. Copyright Office.
			  
			  *************************************************************************
			  END COPYRIGHT
	-->
	<!--
		*****************************************************************************************************************************
		    	Version:  WBI 6.0.2
		*****************************************************************************************************************************
		    	Task:      Create Java binding classes that belong to an SCA module
		*****************************************************************************************************************************
	       	Authors:     Jens Grotrian (jgr@de.ibm.com)
		*****************************************************************************************************************************
	 -->
	<xsl:strip-space elements="*"/>
	<xsl:output method="text" indent="no"/>
	<!--************************************ -->
	<!--*        Configurable parameters   * -->
	<!--************************************ -->
	<!-- "fdlfile": FDL file name -->
	<xsl:param name="fdlfile" select="''"/>
	<!-- "wsdlfile": path of target directory -->
	<xsl:param name="wsdlfile" select="''"/>
	<!-- "outputdir": path of target directory -->
	<xsl:param name="outputdir" select="''"/>
	<!-- "enable_LI339_UPES_Binding" (requires "enable_LI802_Generate_SCDL") -->
	<xsl:param name="enable_LI339_UPES_Binding" select="'TRUE'"/>
	<!-- "temp-Java-file-name-extension": temporary file name extensions for the UPES data binding classes (used before code page conversion) -->
	<xsl:param name="temp-Java-file-name-extension" select="'.jjj'"/>
	<!--************************** -->
	<!--*        Parameters         * -->
	<!--************************** -->
	<!-- "end of line" character string -->
	<xsl:param name="eol" select='"&#xA;"'/>
	<!-- "mqwfTargetNamespace": MQWF target namespace used for UPES message data binding -->
	<xsl:param name="mqwfTargetNamespace" select="'http://www.ibm.com/xmlns/prod/websphere/mqwf/schema/'"/>
	<!-- "mqwfTargetNamespacePrefix": MQWF target namespace prefix -->
	<xsl:param name="mqwfTargetNamespacePrefix" select="'mqwf:'"/>
	<!--
		*** Parameters also used in WSDL file ***
	-->
	<!-- "lower-case-characters": "aäbcdefghijklmnoöpqrstuüvwxyz" -->
	<xsl:param name="lower-case-characters" select="'aäbcdefghijklmnoöpqrstuüvwxyz'"/>
	<!-- "upper-case-characters": "AÄBCDEFGHIJKLMNOÖPQRSTUÜVWXYZ" -->
	<xsl:param name="upper-case-characters" select="'AÄBCDEFGHIJKLMNOÖPQRSTUÜVWXYZ'"/>
	<!-- "UPES-output-message-suffix": Suffix appended to "UPES" output message names -->
	<xsl:param name="UPES-output-message-suffix" select="'_UPES_OUT_MSG'"/>
	<!--
		*** Parameters also used in BPEL files ***
	-->
	<!-- "partner-link-suffix": Suffix appended to "partner link" names -->
	<xsl:param name="partner-link-suffix" select="'_PL'"/>
	<!-- "Error" Message severity 1 -->
	<xsl:param name="Error" select="1"/>
	<!-- "Warning" Message severity 2 -->
	<xsl:param name="Warning" select="2"/>
	<!-- "Information" Message severity 3 -->
	<xsl:param name="Information" select="3"/>
	<!--
		*** Parameters also used in SCDL files ***
	-->
	<!-- "data-binding-suffix": Suffix appended to data binding names -->
	<xsl:param name="data-binding-suffix" select="'_DataBindingImpl'"/>
	<!-- "data-binding-package-name": package name of a data binding Java classes -->
	<xsl:param name="data-binding-package-name" select="'com.ibm.workflow.sca.jms.data'"/>
	<!-- "data-binding-package-relative-path": relative path of data binding Java classes -->
	<xsl:param name="data-binding-package-path" select="'com\ibm\workflow\sca\jms\data\'"/>
	<!-- 
		*****************************************************************************************************************************
		Initial template 
		*****************************************************************************************************************************
	-->
	<xsl:template match="/">
		<xsl:if test="'TRUE' = translate($enable_LI339_UPES_Binding, $lower-case-characters, $upper-case-characters)">
			<xsl:call-template name="create-UPES-data-bindings"/>
		</xsl:if>
	</xsl:template>
	<!--
		*****************************************************************************************************************************
 		Template "create-UPES-data-bindings"
 		
		Creates the data bindings for UPES message types
		*****************************************************************************************************************************
	-->
	<xsl:template name="create-UPES-data-bindings">
		<xsl:variable name="message" select="document($wsdlfile)/wsdls:definitions/wsdls:message"/>
		<!-- For each  UPES message which ends with '_UPES_OUT_MSG' -->
		<xsl:for-each select="xalan:nodeset($message)[ substring(@name, string-length(@name) - string-length($UPES-output-message-suffix) + 1) = $UPES-output-message-suffix ]">
			<xsl:variable name="temp-Java-file-local-name" select="concat(@name, $data-binding-suffix, $temp-Java-file-name-extension)"/>
			<xsl:variable name="Java-file-local-name" select="concat(@name, $data-binding-suffix, '.java')"/>
			<xsl:variable name="Java-file-path-name" select="concat($outputdir, $data-binding-package-path, $temp-Java-file-local-name)"/>
			<xsl:variable name="addJavaFileName" select="java:com.ibm.bpe.fdl2bpel.converter.FileNameList.add($Java-file-path-name)"/>
			<xsl:variable name="message" select="java:com.ibm.bpe.fdl2bpel.converter.CEnv.write($Information, 'writeOutput', $Java-file-local-name)"/>
			<xsl:variable name="message-type" select="substring(current()/wsdls:part/@type, string-length($mqwfTargetNamespacePrefix)+1)"/>
			<redirect:write select="$Java-file-path-name">
				<xsl:call-template name="create-UPES-data-binding">
					<xsl:with-param name="message-name" select="@name"/>
					<xsl:with-param name="message-type" select="$message-type"/>
				</xsl:call-template>
			</redirect:write>
		</xsl:for-each>
	</xsl:template>
	<!-- Generate DataBinding.java file -->
	<!--
		*****************************************************************************************************************************
 		Template "create-UPES-data-binding"
 		
		Creates a Java class file that binds a WSDL message type to a Java data type.
		*****************************************************************************************************************************
	-->
	<xsl:template name="create-UPES-data-binding">
		<xsl:param name="message-name"/>
		<xsl:param name="message-type"/>
		<xsl:variable name="className" select="concat(translate(substring($message-name, 1, 1), $lower-case-characters, $upper-case-characters), substring($message-name, 2))"/>
		<xsl:text>/*</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:text> * Generated by FDL2BPEL converter on </xsl:text>
		<xsl:value-of select="java:java.util.Date.new()"/>
		<xsl:value-of select="$eol"/>
		<xsl:text> * from FDL file </xsl:text>
		<xsl:value-of select="concat('&quot;', $fdlfile, '&quot;')"/>
		<xsl:value-of select="$eol"/>
		<xsl:text> *</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:text> */</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:text>package </xsl:text>
		<xsl:value-of select="$data-binding-package-name"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:value-of select="$eol"/>
		<xsl:text>public class </xsl:text>
		<xsl:value-of select="$className"/>
		<xsl:text>_DataBindingImpl extends WMQWFUpesDataBinding {</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:value-of select="$eol"/>
		<xsl:text>    private static final long serialVersionUID = 1L;</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:value-of select="$eol"/>
		<xsl:text>    public </xsl:text>
		<xsl:value-of select="$className"/>
		<xsl:text>_DataBindingImpl() {</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:text>        super();</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:text>        this.setDataType("</xsl:text>
		<xsl:value-of select="$message-type"/>
		<xsl:text>");</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:text>        this.setDataTypeNameSpace("</xsl:text>
		<xsl:value-of select="$mqwfTargetNamespace"/>
		<xsl:text>");</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:text>    }</xsl:text>
		<xsl:value-of select="$eol"/>
		<xsl:text>}</xsl:text>
		<xsl:value-of select="$eol"/>
	</xsl:template>
</xsl:transform>
