<?xml version="1.0" encoding="UTF-8"?>
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fdl="http://www.ibm.com/workflow/2003" xmlns:xalan="http://xml.apache.org/xalan" extension-element-prefixes="xalan" exclude-result-prefixes="fdl" xmlns="http://www.w3.org/2001/XMLSchema" version="1.0">
	<!--
			  BEGIN CMVC
			  *************************************************************************
			  
			  Workfile: BPCSRVR/ws/code/workflow.fdl2bpel/src/com/ibm/bpe/fdl2bpel/converter/v602/xfdl2bpel_xsd.xsl, WAS.workflow, WBI602.BPCSRVR, m0705.08
			  Last update: 06/11/24 08:04:25
			  SCCS path, id: /family/botp/vc/10/8/3/1/s.76 1.5
			  
			  *************************************************************************
			  END CMVC
			  BEGIN COPYRIGHT
			  *************************************************************************
			  
			  IBM Confidential
			  OCO Source Materials
			  5655-FLW (C) Copyright IBM Corporation 2003, 2006.
			  The source code for this program is not published or otherwise
			  divested of its trade secrets, irrespective of what has been
			  deposited with the U.S. Copyright Office.
			  
			  *************************************************************************
			  END COPYRIGHT
	-->
	<!--
		*****************************************************************************************************************************
		    	Version:  WBI 6.0.2
		*****************************************************************************************************************************
		    	Task:     Create a XMLSchema definition file for the data objects used in BPEL processes
		*****************************************************************************************************************************
	       	Author: Jens Grotrian (jgr@de.ibm.com)
		*****************************************************************************************************************************
	 -->
	<xsl:strip-space elements="*"/>
	<xsl:output method="xml" indent="yes" xalan:indent-amount="5"/>
	<!--************************************ -->
	<!--*      Configurable parameters     * -->
	<!--************************************ -->
	<!-- "createPredefinedDataMembers": Create the predefined MQWF data structure members -->
	<xsl:param name="createPredefinedDataMembers" select="'TRUE'"/>
	<!--************************** -->
	<!--*        Parameters         * -->
	<!--************************** -->
	<!-- "lower-case-characters": "aäbcdefghijklmnoöpqrstuüvwxyz" -->
	<xsl:param name="lower-case-characters" select="'aäbcdefghijklmnoöpqrstuüvwxyz'"/>
	<!-- "Upper-case-characters": "AÄBCDEFGHIJKLMNOÖPQRSTUÜVWXYZ" -->
	<xsl:param name="upper-case-characters" select="'AÄBCDEFGHIJKLMNOÖPQRSTUÜVWXYZ'"/>
	<!-- "message-type-suffix": Suffix appended to message type names -->
	<xsl:param name="message-type-suffix" select="'_MT'"/>
	<!-- "UPES-input-message-type-suffix": Suffix appended to UPES input message type names -->
	<xsl:param name="UPES-input-message-type-suffix" select="'_UPES_IN_MT'"/>
	<!-- "UPES-output-message-type-suffix": Suffix appended to UPES output message type names -->
	<xsl:param name="UPES-output-message-type-suffix" select="'_UPES_OUT_MT'"/>
	<!-- "global-container-suffix": Suffix appended to element definitions that specify a "global container" -->
	<xsl:param name="global-container-suffix" select="'_GC'"/>
	<!--************************** -->
	<!--*        Keys                   * -->
	<!--************************** -->
	<!--
		Key "UPES-activity-receiving-data-structure" represents a "mapping" between
		data structure names (as "key objects") and program activities (as "value objects")
	-->
	<xsl:key name="UPES-activity-receiving-data-structure" match="fdl:programActivity[ fdl:program/@programExecutionUnit ]" use="fdl:input/@type"/>
	<!--************* -->
	<!-- Templates   -->
	<!--************* -->
	<!--
		*****************
		Initial template
		*****************
	-->
	<xsl:template match="/">
		<xsl:apply-templates mode="xsd-definitions"/>
	</xsl:template>
	<!--
		*************************************************************
		Translate "fdl:definitions" into XMLSchema definitions
		*************************************************************
	-->
	<xsl:template match="fdl:definitions" mode="xsd-definitions">
		<schema elementFormDefault="unqualified" attributeFormDefault="qualified" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:mqwf="http://www.ibm.com/xmlns/prod/websphere/mqwf/schema/" targetNamespace="http://www.ibm.com/xmlns/prod/websphere/mqwf/schema/">
			<!-- Create user-defined data structure and message types -->
			<xsl:apply-templates select="fdl:structure | fdl:create/fdl:structure | fdl:update/fdl:structure | fdl:replace/fdl:structure" mode="xsd-definitions"/>
			<!-- Create data structure types required for "UPES" activities-->
			<xsl:call-template name="create-UPES-data-structure-types"/>
		</schema>
	</xsl:template>
	<!--
		******************************************************************
		Translate "fdl:structure" into XMLSchema "complexType"
		******************************************************************
	-->
	<xsl:template match="fdl:structure" mode="xsd-definitions">
		<!--
			Create complex type without "fixed data members".
		-->
		<complexType name="{@name}">
			<xsl:if test="*">
				<xsl:element name="sequence">
					<xsl:apply-templates select="fdl:member" mode="xsd-definitions"/>
				</xsl:element>
			</xsl:if>
		</complexType>
		<!--
			Create "complex type" definitions related to the input/output of a process, activity, or program.
		-->
		<xsl:if test="//*[ ( local-name() = 'process'
							or local-name() = 'programActivity'
							or local-name() = 'processActivity'
							or local-name() = 'block'
							or local-name() = 'program' )
							and (  fdl:input/@type = current()/@name or  fdl:output/@type = current()/@name ) ]">
			<!--
				Create  "complex type" definition that includes the "predefined data members", if it is referenced by some process, activity, or program.
			-->
			<xsl:if test="'TRUE' = translate($createPredefinedDataMembers, $lower-case-characters, $upper-case-characters)">
				<complexType name="{@name}{$message-type-suffix}">
					<sequence>
						<element type="xsd:long" minOccurs="0" nillable="true" name="_RC"/>
						<element type="xsd:string" minOccurs="0" nillable="true" name="_PROCESS"/>
						<element type="xsd:string" minOccurs="0" nillable="true" name="_PROCESS_MODEL"/>
						<element type="xsd:string" minOccurs="0" nillable="true" name="_ACTIVITY"/>
						<element type="mqwf:_PROCESS_INFO" name="_PROCESS_INFO"/>
						<element type="mqwf:_ACTIVITY_INFO" name="_ACTIVITY_INFO"/>
						<element type="mqwf:{@name}" name="_STRUCT"/>
					</sequence>
				</complexType>
			</xsl:if>
			<!--
				Create for each combination of input/output type a UPES input message type if we have an "UPES" activity.
				(You have to consider "combination of input/output types", because the output type determines the type of element "MessageDefaultContainer"!)
			 -->
			<xsl:variable name="current-data-structure-name" select="@name"/>
			<xsl:for-each select="key('UPES-activity-receiving-data-structure', $current-data-structure-name)">
				<xsl:variable name="current-UPES-activity" select="current()"/>
				<xsl:for-each select="ancestor::fdl:definitions/fdl:structure[ @name = $current-UPES-activity/fdl:output/@type ]
											| ancestor::fdl:definitions/fdl:create/fdl:structure[ @name = $current-UPES-activity/fdl:output/@type ]
											| ancestor::fdl:definitions/fdl:update/fdl:structure[ @name = $current-UPES-activity/fdl:output/@type ]
											| ancestor::fdl:definitions/fdl:replace/fdl:structure[ @name = $current-UPES-activity/fdl:output/@type ]">
					<xsl:if test="not(current()/@name = $current-UPES-activity/preceding::fdl:programActivity[ fdl:input/@type = $current-data-structure-name and fdl:program/@programExecutionUnit ]/fdl:output/@type)">
						<xsl:choose>
							<!-- CASE: data structures of input and output are the same (we can use a simple type name) -->
							<xsl:when test="$current-data-structure-name = current()/@name">
								<complexType name="{$current-data-structure-name}{$UPES-input-message-type-suffix}">
									<sequence>
										<element type="mqwf:_MESSAGE_CONTEXT" name="MessageContext"/>
										<element type="mqwf:{$current-data-structure-name}" name="MessageContainer"/>
										<element type="mqwf:{current()/@name}" name="MessageDefaultContainer"/>
									</sequence>
								</complexType>
							</xsl:when>
							<!--
								OTHERWISE: different data structures of input and output (we need the names of input
											    and output data structures in order to prevent type name clashes)
							-->
							<xsl:otherwise>
								<complexType name="{$current-data-structure-name}_{current()/@name}{$UPES-input-message-type-suffix}">
									<sequence>
										<element type="mqwf:_MESSAGE_CONTEXT" name="MessageContext"/>
										<element type="mqwf:{$current-data-structure-name}" name="MessageContainer"/>
										<element type="mqwf:{current()/@name}" name="MessageDefaultContainer"/>
									</sequence>
								</complexType>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
				</xsl:for-each>
			</xsl:for-each>
			<!--
				Create a single UPES output message type if we have an "UPES" activity.
			 -->
			<xsl:if test="//fdl:programActivity[ fdl:output/@type = current()/@name and fdl:program/@programExecutionUnit ]">
				<complexType name="{@name}{$UPES-output-message-type-suffix}">
					<sequence>
						<element type="mqwf:_MESSAGE_CONTEXT" name="MessageContext"/>
						<element type="mqwf:{@name}" name="MessageContainer"/>
					</sequence>
				</complexType>
			</xsl:if>
		</xsl:if>
		<!--
			Create respective "complex type" and element definitions, if the FDL structure is referenced as a "global container" by some process.
		-->
		<xsl:if test="//fdl:process/fdl:globalContainer[ @type= current()/@name ]">
			<xsl:choose>
				<!-- CASE: parameter "createPredefinedDataMembers" is set to "true" -->
				<xsl:when test="'TRUE' = translate($createPredefinedDataMembers, $lower-case-characters, $upper-case-characters)">
					<!--
						Create another "complex type" definition with a single "_STRUCT" element.
					-->
					<complexType name="{@name}{$global-container-suffix}">
						<sequence>
							<element type="mqwf:{@name}" name="_STRUCT"/>
						</sequence>
					</complexType>
					<!--
						Create another "element" definition that refers to the "complex type" definition with a single "_STRUCT" child element
					-->
					<element type="mqwf:{current()/@name}{$global-container-suffix}" name="{current()/@name}{$global-container-suffix}"/>
				</xsl:when>
				<!-- OHERWISE: It is assumed, that parameter "createPredefinedDataMembers" is set to "false" -->
				<xsl:otherwise>
					<!--
						Create another "element" definition that refers to the "complex type" definition without predefined child elements.
					-->
					<element type="mqwf:{current()/@name}" name="{current()/@name}{$global-container-suffix}"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	<!--
		***********************************************************
		Translate "fdl:member" into XMLSchema "element"
		***********************************************************
	-->
	<xsl:template match="fdl:member" mode="xsd-definitions">
		<xsl:variable name="type">
			<xsl:choose>
				<xsl:when test="'STRING' = translate(@type, $lower-case-characters, $upper-case-characters)">
					<xsl:text>xsd:string</xsl:text>
				</xsl:when>
				<xsl:when test="'LONG' = translate(@type, $lower-case-characters, $upper-case-characters)">
					<xsl:text>xsd:long</xsl:text>
				</xsl:when>
				<xsl:when test="'FLOAT' = translate(@type, $lower-case-characters, $upper-case-characters)">
					<xsl:text>xsd:double</xsl:text>
				</xsl:when>
				<xsl:when test="'BINARY' = translate(@type, $lower-case-characters, $upper-case-characters)">
					<xsl:text>xsd:base64Binary</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>mqwf:</xsl:text>
					<xsl:value-of select="@type"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="@cardinality">
				<element maxOccurs="{@cardinality}" type="{$type}" minOccurs="0" nillable="true" name="{@name}"/>
			</xsl:when>
			<xsl:otherwise>
				<element type="{$type}" minOccurs="0" nillable="true" name="{@name}"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
		*************************************************************
		Create "UPES" data structure types
		*************************************************************
	-->
	<xsl:template name="create-UPES-data-structure-types">
		<!-- Create data structure "_MESSAGE_CONTEXT" if there is an "UPES" activity -->
		<xsl:if test="//fdl:programActivity/fdl:program/@programExecutionUnit">
			<complexType name="_MESSAGE_CONTEXT">
				<sequence>
					<element type="xsd:long" minOccurs="0" nillable="true" name="_RC"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="_PROCESS"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="_PROCESS_MODEL"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="_ACTIVITY"/>
					<element type="mqwf:_PROCESS_INFO" minOccurs="0" name="_PROCESS_INFO"/>
					<element type="mqwf:_ACTIVITY_INFO" minOccurs="0" name="_ACTIVITY_INFO"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ResponseRequired"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="UserContext"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="KeepName"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ActImplCorrelID"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="Starter"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProgramName"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="MessageType"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="Origin"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcInstID"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcInstParentName"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcInstTopLevelName"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcInstDescription"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcInstState"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="LastStateChangeTime"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="LastModificationTime"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcTemplID"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcTemplValidFromDate"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="Icon"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="Category"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcInstSuspensionTime"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcInstSuspensionExpirationTime"/>
					<element type="xsd:long" minOccurs="0" nillable="true" name="Rc"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="MessageText"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcTemplName"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ProcInstName"/>
					<element type="xsd:long" minOccurs="0" nillable="true" name="ProgramRC"/>
					<element type="xsd:string" minOccurs="0" nillable="true" name="ExternalProcessContext"/>
				</sequence>
			</complexType>
		</xsl:if>
	</xsl:template>
	<!--
		****************************************************************************************************************
		Template "program-activity-type":

		Determines the type of an FDL program activity.
		Selects from types "empty activity", "service invocation activity" (UPES activity),  "staff activity",
		"assumed staff activity"
		(NOTE THAT THIS TEMPLATE IS SHARED IN "XFDLBPEL_WSDL.XSL" AND "XFDLBPEL_BPEL.XSL"!)
		****************************************************************************************************************
	 -->
	<xsl:template name="program-activity-type">
		<xsl:param name="activity"/>
		<xsl:choose>
			<!--
				CASE: "empty activity"
					A program activity is an "empty activity" if
					1) if the activity implementation is a program with the name FMCINTERNALNOOP
					2) the execution mode is chained
					3) the input and output data structures are the same
			-->
			<xsl:when test="$activity/fdl:program/@name='FMCINTERNALNOOP'
								and $activity/fdl:program/@synchronization='chained'
								and $activity/fdl:input/@type = $activity/fdl:output/@type">
				<xsl:value-of select="'empty activity'"/>
			</xsl:when>
			<!--
				CASE: "service invocation activity"
					A program activity is an "service invocation activity" if a user-defined program execution server
					(UPES) is specified (attribute "fdl:program/@programExecutionUnit").
			-->
			<xsl:when test="$activity/fdl:program/@programExecutionUnit">
				<xsl:value-of select="'service invocation activity'"/>
			</xsl:when>
			<!--
				CASE: "staff activity"
					A program activity is a "staff activity" if the following conditions apply:
					1. Attribute "checkoutPossible" indicates that it can be checked out from the runtime database.
					2. Start type is "manual"
			-->
			<xsl:when test="$activity/fdl:join/@startType='manual' and ( $activity/fdl:defaultSetting/@checkoutPossible='yes'
								 or $activity/ancestor::fdl:process/fdl:activityDefaultSetting/@checkoutPossible='yes' )">
				<xsl:value-of select="'staff activity'"/>
			</xsl:when>
			<!--
				OTHERWISE: "unclassified activity"
					A program activity is an "unclassified activity" if none of the above rules apply.
					In this case assume a "staff activity".
			-->
			<xsl:otherwise>
				<xsl:value-of select="'assumed staff activity'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:transform>
